@@ -29,7 +29,7 @@ use Sim::OPT::Takechance;
 use Sim::OPT::Parcoord3d;
 
 our @ISA = qw( Exporter );
-our @EXPORT = qw( interlinear, interstart );
+our @EXPORT = qw( interlinear, interstart prepfactlev tellstepsize );
 
 $VERSION = '0.033';
 $ABSTRACT = 'Interlinear is a program for building metamodels from incomplete, multivariate, discrete dataseries on the basis of gradients weighted proportionally to multidimensional distances.';
@@ -1587,7 +1587,6 @@ sub interlinear
     #say $tee "ARR AFTER: " . dump( @arr );
     $count++;
   }
-          if ( $relaxmethod eq "logarithmic" )
   return( @arr );
 }
 
